@@ -23,4 +23,5 @@
 #' \item{DB}{Database}
 #' }
 #' @source \url{http://www.scopus.com}
-"garfield"
\ No newline at end of file
+#' @name garfield
+NULL
\ No newline at end of file
